CustomIconButton class

IconButton 图标按钮组件

Inheritance

Constructors

CustomIconButton({required dynamic onPressed()?, required Widget icon, Key? key, double? iconSize, VisualDensity? visualDensity, EdgeInsetsGeometry? padding, AlignmentGeometry? alignment, double? splashRadius, Color? color, Color? focusColor, Color? hoverColor, Color? highlightColor, Color? splashColor, Color? disabledColor, MouseCursor? mouseCursor, FocusNode? focusNode, bool autofocus = false, String? tooltip, bool? enableFeedback, BoxConstraints? constraints, ButtonStyle? style, bool? isSelected, Widget? selectedIcon, CustomIconButtonType? type})
IconButton 图标按钮组件
const

Properties

alignment → AlignmentGeometry?
对齐方式
finalinherited
autofocus → bool
自动聚焦
finalinherited
color → Color?
颜色
finalinherited
constraints → BoxConstraints?
约束
finalinherited
disabledColor → Color?
禁用颜色
finalinherited
enableFeedback → bool?
启用反馈
finalinherited
focusColor → Color?
焦点颜色
finalinherited
focusNode → FocusNode?
焦点节点
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
highlightColor → Color?
高亮颜色
finalinherited
hoverColor → Color?
悬停颜色
finalinherited
icon → Widget
图标
finalinherited
iconSize → double?
图标尺寸
finalinherited
isSelected → bool?
选中状态
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mouseCursor → MouseCursor?
鼠标指针
finalinherited
onPressed → dynamic Function()?
点击回调
finalinherited
padding → EdgeInsetsGeometry?
内边距
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedIcon → Widget?
选中图标
finalinherited
splashColor → Color?
波纹颜色
finalinherited
splashRadius → double?
点击波纹半径
finalinherited
style → ButtonStyle?
样式
finalinherited
tooltip → String?
提示文本
finalinherited
type → CustomIconButtonType?
类型
finalinherited
visualDensity → VisualDensity?
视觉密度
finalinherited

Methods

buildIconButton(BuildContext context, VoidCallback? onPressed, CustomIconButtonType? type) → Widget
构建图标按钮
override
createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → CustomIconButtonBaseState<CustomIconButtonBase>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

filled({required dynamic onPressed(), required Widget icon, Key? key, double? iconSize, VisualDensity? visualDensity, EdgeInsetsGeometry? padding, AlignmentGeometry? alignment, double? splashRadius, Color? color, Color? focusColor, Color? hoverColor, Color? highlightColor, Color? splashColor, Color? disabledColor, MouseCursor? mouseCursor, FocusNode? focusNode, bool autofocus = false, String? tooltip, BoxConstraints? constraints, ButtonStyle? style, Widget? selectedIcon}) → dynamic
填充图标按钮组件
filledTonal({required dynamic onPressed(), required Widget icon, Key? key, double? iconSize, VisualDensity? visualDensity, EdgeInsetsGeometry? padding, AlignmentGeometry? alignment, double? splashRadius, Color? color, Color? focusColor, Color? hoverColor, Color? highlightColor, Color? splashColor, Color? disabledColor, MouseCursor? mouseCursor, FocusNode? focusNode, bool autofocus = false, String? tooltip, BoxConstraints? constraints, ButtonStyle? style, Widget? selectedIcon}) → dynamic
填充色调图标按钮组件
outlined({required dynamic onPressed(), required Widget icon, Key? key, double? iconSize, VisualDensity? visualDensity, EdgeInsetsGeometry? padding, AlignmentGeometry? alignment, double? splashRadius, Color? color, Color? focusColor, Color? hoverColor, Color? highlightColor, Color? splashColor, Color? disabledColor, MouseCursor? mouseCursor, FocusNode? focusNode, bool autofocus = false, String? tooltip, BoxConstraints? constraints, ButtonStyle? style, Widget? selectedIcon}) → dynamic
轮廓图标按钮组件