PickerItem<T> class

选择器项

Constructors

PickerItem({required PickerItemListTile listTile, required T data, required dynamic key})
选择器项

Properties

data ↔ T
数据
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ dynamic
键值
getter/setter pair
listTile ↔ PickerItemListTile
列表项
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited