PickerItemListTile class

选择器列表项 Model

Constructors

PickerItemListTile({required String? title, String? subtitle, String? additionalInfoText, Widget? additionalInfo})
选择器列表项 Model

Properties

additionalInfo ↔ Widget?
附加信息组件
getter/setter pair
additionalInfoText ↔ String?
附加信息文本
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle ↔ String?
副标题
getter/setter pair
title ↔ String?
标题
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited